@@ -3,6 +3,7 @@ import argparse
 import _pickle as pickle
 import sqlite3
 import pandas as pd
+import numpy as np
 
 from collections import Counter, defaultdict
 from Levenshtein import hamming
@@ -38,8 +39,7 @@ class Matcher(Preprocessor):
                preprocessed_files_path='.',
                best_match=False,
                output_format='csv',
-               output_name='',
-               versioned_ids=True):
+               output_name=''):
     
     # passing a Python list is possible, call results generic name 
     # if none is specified
@@ -66,7 +66,6 @@ class Matcher(Preprocessor):
     self.preprocessed_files_path = preprocessed_files_path
     self.best_match = best_match
     self.output_format = output_format
-    self.versioned_ids = versioned_ids
 
     # select format based on # of mismatches to pass to Preprocessor
     # SQLite for exact matching - pickle for mismatching
@@ -109,7 +108,7 @@ class Matcher(Preprocessor):
     if not all([seq.isupper() for seq in self.query]):
       raise ValueError('A peptide in the query contains a lowercase letter.')
 
-    super().__init__(self.proteome, self.preprocess_format, self.preprocessed_files_path, self.versioned_ids)
+    super().__init__(self.proteome, self.preprocess_format, self.preprocessed_files_path, True)
 
   def batch_query(self):
     '''
@@ -263,7 +262,7 @@ class Matcher(Preprocessor):
     # compile all matches into format used for benchmarking (comma separated)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', '', '', '', '', '', '', '', '', ''))
+        all_matches.append((peptide, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan))
       for match in matches:
         # retrieve protein IDs from the other created table
         get_protein_data = f'SELECT * FROM "{names_table_name}" WHERE protein_number = "{(match - (match % 100000)) // 100000}"'
@@ -480,7 +479,7 @@ class Matcher(Preprocessor):
     # (peptide, matched peptide, protein matched in, index, # of mismatches)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', '', '', '', '', '', '', '', '', ''))
+        all_matches.append((peptide, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan))
       else:
         for match in matches:
           all_matches.append((
@@ -561,13 +560,9 @@ class Matcher(Preprocessor):
       # sort values by protein ID and drop duplicates, guaranteeing same results 
       df.sort_values(by='Protein ID', inplace=True)
       df.drop_duplicates(['Query Sequence'], inplace=True)
-    
-    else:
-      # gene priority and protein existence levels not needed if not best match
-      df.drop(columns=['Gene Priority', 'Protein Existence Level'], inplace=True)
-    
-    # drop any columns that are entirely empty (usually gene priority column)
-    df.dropna(how='all', axis=1, inplace=True)
+
+    # drop "Gene Priority" column
+    df.drop(columns=['Gene Priority'], inplace=True)
 
     return df
 
